@@ -31,7 +31,6 @@ class LX200ZEQ25 : public LX200Generic
         virtual bool updateProperties() override;
         virtual bool initProperties() override;
 
-        virtual bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
         virtual bool ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n) override;
 
     protected:
@@ -63,12 +62,17 @@ class LX200ZEQ25 : public LX200Generic
 
         virtual int SendPulseCmd(int8_t direction, uint32_t duration_msec) override;
 
+        // Home
+        virtual IPState ExecuteHomeAction(TelescopeHomeAction action) override;
+
     private:
         int setZEQ25StandardProcedure(int fd, const char *data);
         int setZEQ25Latitude(double Lat);
         int setZEQ25Longitude(double Long);
         int setZEQ25UTCOffset(double hours);
         int setZEQ25Date(int days, int months, int years);
+        int setZEQ25ObjectRA(int fd, double ra);
+        int setZEQ25ObjectDEC(int fd, double dec);
         bool slewZEQ25();
         int moveZEQ25To(int direction);
         int haltZEQ25Movement();
@@ -88,9 +92,6 @@ class LX200ZEQ25 : public LX200Generic
         bool getMountInfo();
         void mountSim();
 
-        ISwitch HomeS[1];
-        ISwitchVectorProperty HomeSP;
-
         /* Guide Rate */
         INumber GuideRateN[1];
         INumberVectorProperty GuideRateNP;
