@@ -104,7 +104,7 @@ bool Manager::ISNewNumber(const char *dev, const char *name, double values[], ch
 }
 
 bool Manager::ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
-               char *names[], int num)
+                        char *names[], int num)
 {
     bool r = false;
     r |= convolution->ISNewBLOB(dev, name, sizes, blobsizes, blobs, formats, names, num);
@@ -139,5 +139,13 @@ bool Manager::processBLOB(uint8_t* buf, uint32_t ndims, int* dims, int bits_per_
     r |= wavelets->processBLOB(buf, ndims, dims, bits_per_sample);
     return r;
 }
-
+void Manager::setCaptureFileExtension(const char *ext)
+{
+    convolution->setCaptureFileExtension(ext);
+    dft->setCaptureFileExtension(ext);
+    idft->setCaptureFileExtension(ext);
+    spectrum->setCaptureFileExtension(ext);
+    histogram->setCaptureFileExtension(ext);
+    wavelets->setCaptureFileExtension(ext);
+}
 }
