@@ -22,6 +22,7 @@
 #include "base64.h"
 #include "config.h"
 #include "indicom.h"
+#include "sharedblob.h"
 #include "indistandardproperty.h"
 #include "locale_compat.h"
 
@@ -131,8 +132,8 @@ IPerm BaseDevice::getPropertyPermission(const char *name) const
 
 void *BaseDevice::getRawProperty(const char *name, INDI_PROPERTY_TYPE type) const
 {
-    INDI::Property *prop = getProperty(name, type);
-    return prop != nullptr ? prop->getProperty() : nullptr;
+    INDI::Property prop = getProperty(name, type);
+    return prop ? prop.getProperty() : nullptr;
 }
 
 INDI::Property BaseDevice::getProperty(const char *name, INDI_PROPERTY_TYPE type) const
@@ -210,6 +211,45 @@ int BaseDevice::removeProperty(const char *name, char *errmsg)
     return result;
 }
 
+std::string BaseDevice::getSharedFilePath(std::string fileName)
+{
+    std::string pathName;
+
+    struct stat st;
+
+    // absolute file path
+    if (stat(fileName.c_str(), &st) == 0)
+    {
+        pathName = fileName;
+        return pathName;
+    }
+
+    // get base name of file
+    const size_t lastSlashIdx = fileName.find_last_of("\\/");
+    if (std::string::npos != lastSlashIdx)
+    {
+        fileName.erase(0, lastSlashIdx + 1);
+    }
+
+    const char * indiprefix = getenv("INDIPREFIX");
+    if (indiprefix)
+    {
+#if defined(OSX_EMBEDED_MODE)
+        pathName  = std::string(indiprefix) + "/Contents/Resources/" + fileName;
+#elif defined(__APPLE__)
+        pathName  = std::string(indiprefix) + "/Contents/Resources/DriverSupport/" + fileName;
+#else
+        pathName  = std::string(indiprefix) + "/share/indi/" + fileName;
+#endif
+    }
+    else
+    {
+        pathName = std::string(DATA_INSTALL_DIR) + "/" + fileName;
+    }
+    return pathName;
+}
+
+
 static std::string sGetSheletonFilePath(std::string fileName)
 {
     std::string pathName;
@@ -334,7 +374,7 @@ int BaseDevice::buildProp(const INDI::LilXmlElement &root, char *errmsg, bool is
             INDI::PropertyNumber typedProperty {0};
             for (const auto &element : root.getElementsByTagName("defNumber"))
             {
-                INDI::WidgetView<INumber> widget;
+                INDI::WidgetViewNumber widget;
 
                 widget.setParent(typedProperty.getNumber());
 
@@ -360,7 +400,7 @@ int BaseDevice::buildProp(const INDI::LilXmlElement &root, char *errmsg, bool is
             typedProperty.setRule(root.getAttribute("rule"));
             for (const auto &element : root.getElementsByTagName("defSwitch"))
             {
-                INDI::WidgetView<ISwitch> widget;
+                INDI::WidgetViewSwitch widget;
 
                 widget.setParent(typedProperty.getSwitch());
 
@@ -381,7 +421,7 @@ int BaseDevice::buildProp(const INDI::LilXmlElement &root, char *errmsg, bool is
             INDI::PropertyText typedProperty {0};
             for (const auto &element : root.getElementsByTagName("defText"))
             {
-                INDI::WidgetView<IText> widget;
+                INDI::WidgetViewText widget;
 
                 widget.setParent(typedProperty.getText());
 
@@ -402,7 +442,7 @@ int BaseDevice::buildProp(const INDI::LilXmlElement &root, char *errmsg, bool is
             INDI::PropertyLight typedProperty {0};
             for (const auto &element : root.getElementsByTagName("defLight"))
             {
-                INDI::WidgetView<ILight> widget;
+                INDI::WidgetViewLight widget;
 
                 widget.setParent(typedProperty.getLight());
 
@@ -421,9 +461,18 @@ int BaseDevice::buildProp(const INDI::LilXmlElement &root, char *errmsg, bool is
         case INDI_BLOB:
         {
             INDI::PropertyBlob typedProperty {0};
+            typedProperty.setBlobDeleter([](void * &blob)
+            {
+#ifdef ENABLE_INDI_SHARED_MEMORY
+                IDSharedBlobFree(blob);
+#else
+                free(blob);
+#endif
+                blob = nullptr;
+            });
             for (const auto &element : root.getElementsByTagName("defBLOB"))
             {
-                INDI::WidgetView<IBLOB> widget;
+                INDI::WidgetViewBlob widget;
 
                 widget.setParent(typedProperty.getBLOB());
 
@@ -484,9 +533,9 @@ bool BaseDevice::isConnected() const
     if (!svp)
         return false;
 
-    auto sp = svp->findWidgetByName("CONNECT");
+    auto sp = svp.findWidgetByName("CONNECT");
 
-    return sp && sp->getState() == ISS_ON && svp->getState() == IPS_OK;
+    return sp && sp->getState() == ISS_ON && svp.getState() == IPS_OK;
 }
 
 void BaseDevice::attach()
@@ -656,7 +705,7 @@ int BaseDevice::setValue(const INDI::LilXmlElement &root, char *errmsg)
 }
 
 #ifdef ENABLE_INDI_SHARED_MEMORY
-static bool sSharedToBlob(const INDI::LilXmlElement &element, INDI::WidgetView<IBLOB> &widget)
+static bool sSharedToBlob(const INDI::LilXmlElement &element, INDI::WidgetViewBlob &widget)
 {
     auto attachementId = element.getAttribute("attached-data-id");
 
@@ -728,7 +777,7 @@ int BaseDevicePrivate::setBLOB(INDI::PropertyBlob property, const LilXmlElement
             size_t base64_encoded_size = element.context().size();
             size_t base64_decoded_size = 3 * base64_encoded_size / 4;
             widget->setBlob(realloc(widget->getBlob(), base64_decoded_size));
-            size_t blobLen = from64tobits_fast(static_cast<char *>(widget->getBlob()), element.context(), base64_encoded_size);
+            int blobLen = from64tobits_fast(static_cast<char *>(widget->getBlob()), element.context(), base64_encoded_size);
             widget->setBlobLen(blobLen);
         }
 
@@ -828,7 +877,7 @@ void BaseDevice::doMessage(XMLEle *msg)
     if (time_stamp)
         snprintf(msgBuffer, MAXRBUF, "%s: %s ", valuXMLAtt(time_stamp), valuXMLAtt(message));
     else
-        snprintf(msgBuffer, MAXRBUF, "%s: %s ", timestamp(), valuXMLAtt(message));
+        snprintf(msgBuffer, MAXRBUF, "%s: %s ", indi_timestamp(), valuXMLAtt(message));
 
     std::string finalMsg = msgBuffer;
 
@@ -843,7 +892,7 @@ void BaseDevice::addMessage(const std::string &msg)
     d->messageLog.push_back(msg);
     guard.unlock();
 
-    d->mediateNewMessage(*this, d->messageLog.size() - 1);
+    d->mediateNewMessage(*this, int(d->messageLog.size() - 1));
 }
 
 const std::string &BaseDevice::messageQueue(size_t index) const
@@ -868,10 +917,18 @@ bool BaseDevice::isValid() const
     return d->valid;
 }
 
-void BaseDevice::watchProperty(const char *name, const std::function<void(INDI::Property)> &callback)
+void BaseDevice::watchProperty(const char *name, const std::function<void(INDI::Property)> &callback, WATCH watch)
 {
     D_PTR(BaseDevice);
-    d->watchPropertyMap[name] = callback;
+    d->watchPropertyMap[name].callback = callback;
+    d->watchPropertyMap[name].watch = watch;
+
+    // call callback function if property already exists
+    INDI::Property property = getProperty(name);
+    if (property.isValid())
+    {
+        callback(property);
+    }
 }
 
 void BaseDevice::registerProperty(const INDI::Property &property)
@@ -897,37 +954,20 @@ void BaseDevice::registerProperty(const INDI::Property &property, INDI_PROPERTY_
 
 const char *BaseDevice::getDriverName() const
 {
-    auto driverInfo = getText("DRIVER_INFO");
-
-    if (!driverInfo)
-        return nullptr;
-
-    auto driverName = driverInfo->findWidgetByName("DRIVER_NAME");
+    auto driverName = getText("DRIVER_INFO").findWidgetByName("DRIVER_NAME");
 
     return driverName ? driverName->getText() : nullptr;
 }
 
 const char *BaseDevice::getDriverExec() const
 {
-    auto driverInfo = getText("DRIVER_INFO");
-
-    if (!driverInfo)
-        return nullptr;
-
-    auto driverExec = driverInfo->findWidgetByName("DRIVER_EXEC");
-
+    auto driverExec = getText("DRIVER_INFO").findWidgetByName("DRIVER_EXEC");
     return driverExec ? driverExec->getText() : nullptr;
 }
 
 const char *BaseDevice::getDriverVersion() const
 {
-    auto driverInfo = getText("DRIVER_INFO");
-
-    if (!driverInfo)
-        return nullptr;
-
-    auto driverVersion = driverInfo->findWidgetByName("DRIVER_VERSION");
-
+    auto driverVersion = getText("DRIVER_INFO").findWidgetByName("DRIVER_VERSION");
     return driverVersion ? driverVersion->getText() : nullptr;
 }
 
